const electron = require('electron')

// Module to control application life.
const app = electron.app
// Module to create native browser window.
const BrowserWindow = electron.BrowserWindow
// Module menu
const Menu = electron.Menu

const path = require('path');
const url = require('url');

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
let mainWindow

function createMenu () {
	// Create menu
const template = [
  {
    label: 'Edit',
    submenu: [
      {
        role: 'undo'
      },
      {
        role: 'redo'
      },
      {
        type: 'separator'
      },
      {
        role: 'cut'
      },
      {
        role: 'copy'
      },
      {
        role: 'paste'
      }
    ]
  },
  {
    label: 'View',
    submenu: [
      {
        role: 'reload'
      },
      {
        type: 'separator'
      },
      {
        role: 'resetzoom'
      },
      {
        role: 'zoomin'
      },
      {
        role: 'zoomout'
      },
      {
        type: 'separator'
      },
      {
        role: 'togglefullscreen'
      }
    ]
  },
  {
    role: 'window',
    submenu: [
      {
        role: 'minimize'
      },
      {
        role: 'close'
      }
    ]
  },
  {
    role: 'help',
    submenu: [
      {
        label: 'Learn More',
        click () { require('electron').shell.openExternal('http://tasksinabox.uservoice.com') }
      }
    ]
  }
]

if (process.platform === 'darwin') {
  template.unshift({
    label: app.getName(),
    submenu: [
      {
        role: 'about'
      },
      {
        type: 'separator'
      },
      {
        role: 'services',
        submenu: []
      },
      {
        type: 'separator'
      },
      {
        role: 'hide'
      },
      {
        role: 'hideothers'
      },
      {
        role: 'unhide'
      },
      {
        type: 'separator'
      },
      {
        role: 'quit'
      }
    ]
  })
  // Edit menu.
  template[1].submenu.push(
    {
      type: 'separator'
    },
    {
      label: 'Speech',
      submenu: [
        {
          role: 'startspeaking'
        },
        {
          role: 'stopspeaking'
        }
      ]
    }
  )
  // Window menu.
  template[3].submenu = [
    {
      label: 'Close',
      accelerator: 'CmdOrCtrl+W',
      role: 'close'
    },
    {
      label: 'Minimize',
      accelerator: 'CmdOrCtrl+M',
      role: 'minimize'
    },
    {
      label: 'Zoom',
      role: 'zoom'
    },
    {
      type: 'separator'
    },
    {
      label: 'Bring All to Front',
      role: 'front'
    }
  ]
}

const menu = Menu.buildFromTemplate(template)
Menu.setApplicationMenu(menu)
}

function createWindow () {
  if (process.platform === 'darwin') {
    createMenu();
  }

  var path = require("path");
  var fs = require("fs");
  var initPath = path.join(app.getPath('appData'), "init.json");

  // Read init data
  var initData;
  try {
    initData = JSON.parse(fs.readFileSync(initPath, 'utf8'));
  }
  catch(e) {
  }

  // Create the browser window.
  mainWindow = new BrowserWindow({
  	width: (initData && initData.bounds) ? initData.bounds.width : 1200, 
  	height: (initData && initData.bounds) ? initData.bounds.height : 680,
    minWidth: 992,
  	titleBarStyle: 'hidden-inset',
  	webPreferences: {
  		nodeIntegration: false
  	} 
  });

  if (process.platform !== 'darwin') {
    mainWindow.setMenu(null);
  }	

  const filter = {
  	urls: ['https://app.tasksinabox.com/*', 'file://*']
  }

  mainWindow.webContents.session.webRequest.onBeforeSendHeaders(filter, (details, callback) => {
	var platform = (process.platform === 'darwin') ? 'mac' : 'win';

  	details.requestHeaders['X-Platform'] = platform;
  	callback({cancel: false, requestHeaders: details.requestHeaders});
  })

  mainWindow.loadURL(url.format({
    pathname: path.join(__dirname, 'index.html'),
    protocol: 'file:',
    slashes: true
  }));

  mainWindow.webContents.on('dom-ready', function (ev) {
  	//mainWindow.webContents.insertCSS('.icon.icon-home { display: none !important; } .quick-launch .quick-launch-header, .tasks-summary-title, .section-nav-bar, .sub-nav-bar { -webkit-app-region: drag }');
  });

  mainWindow.webContents.on('new-window', function(ev, url){
    ev.preventDefault();
    electron.shell.openExternal(url);
  });

  // Open the DevTools.
  //mainWindow.webContents.openDevTools();

  // Emitted before the window gets closed
  mainWindow.on("close", function() {
    var data = {
      bounds: mainWindow.getBounds()
    };
    fs.writeFileSync(initPath, JSON.stringify(data));
  });

  // Emitted when the window is closed.
  mainWindow.on('closed', function () {
    // Dereference the window object, usually you would store windows
    // in an array if your app supports multi windows, this is the time
    // when you should delete the corresponding element.
    mainWindow = null
  });
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on('ready', createWindow)

// Quit when all windows are closed.
app.on('window-all-closed', function () {
  // On OS X it is common for applications and their menu bar
  // to stay active until the user quits explicitly with Cmd + Q
  if (process.platform !== 'darwin') {
    app.quit()
  }
})

app.on('activate', function () {
  // On OS X it's common to re-create a window in the app when the
  // dock icon is clicked and there are no other windows open.
  if (mainWindow === null) {
    createWindow()
  }
})
